==> aws-cdk-scala-workspaces_3-0.1.7-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html","n":"workspaces","t":"workspaces","d":"","k":"static"},
{"l":"io/burkard/cdk/services/workspaces.html","n":"io.burkard.cdk.services.workspaces","t":"package io.burkard.cdk.services.workspaces","d":"io/burkard/cdk/services/workspaces","k":"package"},
{"l":"io/burkard/cdk/services/workspaces/CfnConnectionAlias$.html","n":"CfnConnectionAlias","t":"object CfnConnectionAlias","d":"io/burkard/cdk/services/workspaces/CfnConnectionAlias$","k":"object"},
{"l":"io/burkard/cdk/services/workspaces/CfnConnectionAlias$.html","n":"apply","t":"def apply(internalResourceId: String, connectionString: String, tags: Option[List[_ <: CfnTag]])(implicit stackCtx: Stack): CfnConnectionAlias","d":"io/burkard/cdk/services/workspaces/CfnConnectionAlias$","k":"def"},
{"l":"io/burkard/cdk/services/workspaces/CfnConnectionAliasProps$.html","n":"CfnConnectionAliasProps","t":"object CfnConnectionAliasProps","d":"io/burkard/cdk/services/workspaces/CfnConnectionAliasProps$","k":"object"},
{"l":"io/burkard/cdk/services/workspaces/CfnConnectionAliasProps$.html","n":"apply","t":"def apply(connectionString: String, tags: Option[List[_ <: CfnTag]]): CfnConnectionAliasProps","d":"io/burkard/cdk/services/workspaces/CfnConnectionAliasProps$","k":"def"},
{"l":"io/burkard/cdk/services/workspaces/CfnWorkspace$.html","n":"CfnWorkspace","t":"object CfnWorkspace","d":"io/burkard/cdk/services/workspaces/CfnWorkspace$","k":"object"},
{"l":"io/burkard/cdk/services/workspaces/CfnWorkspace$.html","n":"apply","t":"def apply(internalResourceId: String, bundleId: String, userName: String, directoryId: String, rootVolumeEncryptionEnabled: Option[Boolean], workspaceProperties: Option[WorkspacePropertiesProperty], volumeEncryptionKey: Option[String], tags: Option[List[_ <: CfnTag]], userVolumeEncryptionEnabled: Option[Boolean])(implicit stackCtx: Stack): CfnWorkspace","d":"io/burkard/cdk/services/workspaces/CfnWorkspace$","k":"def"},
{"l":"io/burkard/cdk/services/workspaces/CfnWorkspaceProps$.html","n":"CfnWorkspaceProps","t":"object CfnWorkspaceProps","d":"io/burkard/cdk/services/workspaces/CfnWorkspaceProps$","k":"object"},
{"l":"io/burkard/cdk/services/workspaces/CfnWorkspaceProps$.html","n":"apply","t":"def apply(bundleId: String, userName: String, directoryId: String, rootVolumeEncryptionEnabled: Option[Boolean], workspaceProperties: Option[WorkspacePropertiesProperty], volumeEncryptionKey: Option[String], tags: Option[List[_ <: CfnTag]], userVolumeEncryptionEnabled: Option[Boolean]): CfnWorkspaceProps","d":"io/burkard/cdk/services/workspaces/CfnWorkspaceProps$","k":"def"},
{"l":"io/burkard/cdk/services/workspaces/ConnectionAliasAssociationProperty$.html","n":"ConnectionAliasAssociationProperty","t":"object ConnectionAliasAssociationProperty","d":"io/burkard/cdk/services/workspaces/ConnectionAliasAssociationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/workspaces/ConnectionAliasAssociationProperty$.html","n":"apply","t":"def apply(resourceId: Option[String], connectionIdentifier: Option[String], associationStatus: Option[String], associatedAccountId: Option[String]): ConnectionAliasAssociationProperty","d":"io/burkard/cdk/services/workspaces/ConnectionAliasAssociationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/workspaces/WorkspacePropertiesProperty$.html","n":"WorkspacePropertiesProperty","t":"object WorkspacePropertiesProperty","d":"io/burkard/cdk/services/workspaces/WorkspacePropertiesProperty$","k":"object"},
{"l":"io/burkard/cdk/services/workspaces/WorkspacePropertiesProperty$.html","n":"apply","t":"def apply(userVolumeSizeGib: Option[Number], rootVolumeSizeGib: Option[Number], runningMode: Option[String], runningModeAutoStopTimeoutInMinutes: Option[Number], computeTypeName: Option[String]): WorkspacePropertiesProperty","d":"io/burkard/cdk/services/workspaces/WorkspacePropertiesProperty$","k":"def"},
{"l":"docs/index.html","n":"workspaces","t":"workspaces","d":"","k":"static"}];

==> aws-cdk-scala-workspaces_3-0.4.1-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html","n":"workspaces","t":"workspaces","d":"","k":"static"},
{"l":"io/burkard/cdk/services/workspaces.html","n":"io.burkard.cdk.services.workspaces","t":"package io.burkard.cdk.services.workspaces","d":"io/burkard/cdk/services/workspaces","k":"package"},
{"l":"io/burkard/cdk/services/workspaces/CfnConnectionAlias$.html","n":"CfnConnectionAlias","t":"object CfnConnectionAlias","d":"io/burkard/cdk/services/workspaces/CfnConnectionAlias$","k":"object"},
{"l":"io/burkard/cdk/services/workspaces/CfnConnectionAlias$.html","n":"apply","t":"def apply(internalResourceId: String, connectionString: String, tags: Option[List[_ <: CfnTag]])(implicit stackCtx: Stack): CfnConnectionAlias","d":"io/burkard/cdk/services/workspaces/CfnConnectionAlias$","k":"def"},
{"l":"io/burkard/cdk/services/workspaces/CfnConnectionAliasProps$.html","n":"CfnConnectionAliasProps","t":"object CfnConnectionAliasProps","d":"io/burkard/cdk/services/workspaces/CfnConnectionAliasProps$","k":"object"},
{"l":"io/burkard/cdk/services/workspaces/CfnConnectionAliasProps$.html","n":"apply","t":"def apply(connectionString: String, tags: Option[List[_ <: CfnTag]]): CfnConnectionAliasProps","d":"io/burkard/cdk/services/workspaces/CfnConnectionAliasProps$","k":"def"},
{"l":"io/burkard/cdk/services/workspaces/CfnWorkspace$.html","n":"CfnWorkspace","t":"object CfnWorkspace","d":"io/burkard/cdk/services/workspaces/CfnWorkspace$","k":"object"},
{"l":"io/burkard/cdk/services/workspaces/CfnWorkspace$.html","n":"apply","t":"def apply(internalResourceId: String, bundleId: String, directoryId: String, userName: String, volumeEncryptionKey: Option[String], tags: Option[List[_ <: CfnTag]], rootVolumeEncryptionEnabled: Option[Boolean], userVolumeEncryptionEnabled: Option[Boolean], workspaceProperties: Option[WorkspacePropertiesProperty])(implicit stackCtx: Stack): CfnWorkspace","d":"io/burkard/cdk/services/workspaces/CfnWorkspace$","k":"def"},
{"l":"io/burkard/cdk/services/workspaces/CfnWorkspaceProps$.html","n":"CfnWorkspaceProps","t":"object CfnWorkspaceProps","d":"io/burkard/cdk/services/workspaces/CfnWorkspaceProps$","k":"object"},
{"l":"io/burkard/cdk/services/workspaces/CfnWorkspaceProps$.html","n":"apply","t":"def apply(bundleId: String, directoryId: String, userName: String, volumeEncryptionKey: Option[String], tags: Option[List[_ <: CfnTag]], rootVolumeEncryptionEnabled: Option[Boolean], userVolumeEncryptionEnabled: Option[Boolean], workspaceProperties: Option[WorkspacePropertiesProperty]): CfnWorkspaceProps","d":"io/burkard/cdk/services/workspaces/CfnWorkspaceProps$","k":"def"},
{"l":"io/burkard/cdk/services/workspaces/ConnectionAliasAssociationProperty$.html","n":"ConnectionAliasAssociationProperty","t":"object ConnectionAliasAssociationProperty","d":"io/burkard/cdk/services/workspaces/ConnectionAliasAssociationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/workspaces/ConnectionAliasAssociationProperty$.html","n":"apply","t":"def apply(resourceId: Option[String], associatedAccountId: Option[String], associationStatus: Option[String], connectionIdentifier: Option[String]): ConnectionAliasAssociationProperty","d":"io/burkard/cdk/services/workspaces/ConnectionAliasAssociationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/workspaces/WorkspacePropertiesProperty$.html","n":"WorkspacePropertiesProperty","t":"object WorkspacePropertiesProperty","d":"io/burkard/cdk/services/workspaces/WorkspacePropertiesProperty$","k":"object"},
{"l":"io/burkard/cdk/services/workspaces/WorkspacePropertiesProperty$.html","n":"apply","t":"def apply(userVolumeSizeGib: Option[Number], rootVolumeSizeGib: Option[Number], runningMode: Option[String], runningModeAutoStopTimeoutInMinutes: Option[Number], computeTypeName: Option[String]): WorkspacePropertiesProperty","d":"io/burkard/cdk/services/workspaces/WorkspacePropertiesProperty$","k":"def"},
{"l":"docs/index.html","n":"workspaces","t":"workspaces","d":"","k":"static"}];
